@@ -132,7 +132,6 @@ class DBManager:
 
                 self.ssh_user = ssh_user if ssh_user else self._config.get_env('SSH_USER')
                 self.ssh_key_path = ssh_key_path if ssh_key_path else self._config.get_env('SSH_KEY_PATH')
-                self.db_port = ssh_remote_bind_port if ssh_local_bind_port else int(self._config.get_env('DB_PORT'))
                 self.ssh_local_bind_address = ssh_local_bind_address if ssh_local_bind_address else self._config.ssh_local_bind_port
                 self.ssh_local_bind_port = ssh_local_bind_port if ssh_local_bind_port else self._config.get_env(
                     'SSH_LOCAL_BIND_PORT')
@@ -140,7 +139,7 @@ class DBManager:
             self._page_size = None
 
         # Convert DB port if needed.
-        if not isinstance(int, self._db_port):
+        if not isinstance(self._db_port, int):
             self._db_port = int(self._db_port)
 
     def _get_random_port(self, port):
